pub struct WorkflowLevelArtifactGC {
pub force_finalizer_removal: Option<bool>,
pub pod_metadata: Option<Box<Metadata>>,
pub pod_spec_patch: Option<String>,
pub service_account_name: Option<String>,
pub strategy: Option<String>,
}Expand description
WorkflowLevelArtifactGC describes how to delete artifacts from
completed Workflows - this spec is used on the Workflow level.
Fields
force_finalizer_removal: Option<bool>ForceFinalizerRemoval: if set to true, the finalizer
will be removed in the case that Artifact GC fails
pod_metadata: Option<Box<Metadata>>pod_spec_patch: Option<String>PodSpecPatch holds strategic merge patch to apply against the artgc pod spec.
service_account_name: Option<String>ServiceAccountName is an optional field for specifying
the Service Account that should be assigned to the Pod doing the deletion
strategy: Option<String>Strategy is the strategy to use.
Implementations