pub struct Template {Show 39 fields
pub active_deadline_seconds: Option<String>,
pub affinity: Option<Box<Affinity>>,
pub archive_location: Option<Box<ArtifactLocation>>,
pub automount_service_account_token: Option<bool>,
pub container: Option<Box<Container>>,
pub container_set: Option<Box<ContainerSetTemplate>>,
pub daemon: Option<bool>,
pub dag: Option<Box<DAGTemplate>>,
pub data: Option<Box<Data>>,
pub executor: Option<Box<ExecutorConfig>>,
pub fail_fast: Option<bool>,
pub host_aliases: Option<Vec<HostAlias>>,
pub http: Option<Box<HTTP>>,
pub init_containers: Option<Vec<UserContainer>>,
pub inputs: Option<Box<Inputs>>,
pub memoize: Option<Box<Memoize>>,
pub metadata: Option<Box<Metadata>>,
pub metrics: Option<Box<Metrics>>,
pub name: Option<String>,
pub node_selector: Option<HashMap<String, String>>,
pub outputs: Option<Box<Outputs>>,
pub parallelism: Option<i32>,
pub plugin: Option<Value>,
pub pod_spec_patch: Option<String>,
pub priority: Option<i32>,
pub priority_class_name: Option<String>,
pub resource: Option<Box<ResourceTemplate>>,
pub retry_strategy: Option<Box<RetryStrategy>>,
pub scheduler_name: Option<String>,
pub script: Option<Box<ScriptTemplate>>,
pub security_context: Option<Box<PodSecurityContext>>,
pub service_account_name: Option<String>,
pub sidecars: Option<Vec<UserContainer>>,
pub steps: Option<Vec<Vec<WorkflowStep>>>,
pub suspend: Option<Box<SuspendTemplate>>,
pub synchronization: Option<Box<Synchronization>>,
pub timeout: Option<String>,
pub tolerations: Option<Vec<Toleration>>,
pub volumes: Option<Vec<Volume>>,
}Expand description
Template is a reusable and composable unit of execution in a workflow.
Fields
active_deadline_seconds: Option<String>affinity: Option<Box<Affinity>>archive_location: Option<Box<ArtifactLocation>>automount_service_account_token: Option<bool>AutomountServiceAccountToken indicates whether a service account
token should be automatically mounted in pods. ServiceAccountName
of ExecutorConfig must be specified if this value is false.
container: Option<Box<Container>>container_set: Option<Box<ContainerSetTemplate>>daemon: Option<bool>Daemon will allow a workflow to proceed to the next step so
long as the container reaches readiness.
dag: Option<Box<DAGTemplate>>data: Option<Box<Data>>executor: Option<Box<ExecutorConfig>>fail_fast: Option<bool>FailFast, if specified, will fail this template if any of its child
pods has failed. This is useful for when this template is expanded
with withItems, etc.
host_aliases: Option<Vec<HostAlias>>HostAliases is an optional list of hosts and IPs that will be injected
into the pod spec.
http: Option<Box<HTTP>>init_containers: Option<Vec<UserContainer>>InitContainers is a list of containers which run before the main container.
inputs: Option<Box<Inputs>>memoize: Option<Box<Memoize>>metadata: Option<Box<Metadata>>metrics: Option<Box<Metrics>>name: Option<String>Name is the name of the template
node_selector: Option<HashMap<String, String>>NodeSelector is a selector to schedule this step of the workflow to be run
on the selected node(s). Overrides the selector set at the workflow level.
outputs: Option<Box<Outputs>>parallelism: Option<i32>Parallelism limits the max total parallel pods that can execute at the same time
within the boundaries of this template invocation. If additional steps/dag templates
are invoked, the pods created by those templates will not be counted towards this total.
plugin: Option<Value>Plugin is an Object with exactly one key
pod_spec_patch: Option<String>PodSpecPatch holds strategic merge patch to apply against the pod spec.Allows
parameterization of container fields which are not strings (e.g. resource limits).
priority: Option<i32>Priority to apply to workflow pods.
priority_class_name: Option<String>PriorityClassName to apply to workflow pods.
resource: Option<Box<ResourceTemplate>>retry_strategy: Option<Box<RetryStrategy>>scheduler_name: Option<String>If specified, the pod will be dispatched by specified scheduler. Or it will be dispatched by workflow scope scheduler if specified. If neither specified, the pod will be dispatched by default scheduler.
script: Option<Box<ScriptTemplate>>security_context: Option<Box<PodSecurityContext>>service_account_name: Option<String>ServiceAccountName to apply to workflow pods
sidecars: Option<Vec<UserContainer>>Sidecars is a list of containers which run alongside the main container.
Sidecars are automatically killed when the main container completes
steps: Option<Vec<Vec<WorkflowStep>>>Steps define a series of sequential/parallel workflow steps
suspend: Option<Box<SuspendTemplate>>synchronization: Option<Box<Synchronization>>timeout: Option<String>Timeout allows to set the total node execution timeout duration counting from
the node’s start time. This duration also includes time in which the node spends
in Pending state. This duration may not be applied to Step or DAG templates.
tolerations: Option<Vec<Toleration>>Tolerations to apply to workflow pods.
volumes: Option<Vec<Volume>>Volumes is a list of volumes that can be mounted by containers in a template.