pub struct Parameter {
pub default: Option<String>,
pub description: Option<String>,
pub enum: Option<Vec<String>>,
pub global_name: Option<String>,
pub name: String,
pub value: Option<String>,
pub value_from: Option<Box<ValueFrom>>,
}Expand description
Parameter indicate a passed string parameter to a service template with an optional default value.
Fields
default: Option<String>Default is the default value to use for an input parameter if a value was not supplied.
description: Option<String>Description is the parameter description
enum: Option<Vec<String>>Enum holds a list of string values to choose from, for the actual value of the parameter.
global_name: Option<String>GlobalName exports an output parameter to the global scope, making it available as ’{{io.argoproj.workflow.v1alpha1.outputs.parameters.XXXX}} and in workflow.status.outputs.parameters.
name: StringName is the parameter name.
value: Option<String>Value is the literal value to use for the parameter. If specified in the context of an input parameter, the value takes precedence over any passed values.
value_from: Option<Box<ValueFrom>>Implementations